import { inject, injectable } from "tsyringe";
import { HarmonyDataProvider } from "../dataProviders/harmonyDataProvider";
import { StateDataProvider } from "../dataProviders/stateDataProvider";
import { HarmonyDevice } from "../models/harmonyDevice";

@injectable()
export class VolumeService {
  constructor(
    @inject(StateDataProvider) private _stateDataProvider: StateDataProvider,
    @inject(HarmonyDataProvider)
    private _harmonyDataProvider: HarmonyDataProvider
  ) {}

  /**
   * Turn the volume up for the current running activity.
   */
  public volumeUp = async (controlUnitName: string) => {
    let volumeUpCommand: string = "Volume Up";
    let currentActivity = this._stateDataProvider.getState(controlUnitName);
    if (currentActivity) {
      let volumeDevice: HarmonyDevice =
        this._harmonyDataProvider.getDeviceByName(currentActivity.VolumeDevice);
      await this._harmonyDataProvider.sendCommand(
        volumeUpCommand,
        volumeDevice
      );
    }
  };

  /**
   * Volume down for current running activity.
   */
  public volumeDown = async (controlUnitName: string) => {
    let volumeDownCommand: string = "Volume Down";
    let currentActivity = this._stateDataProvider.getState(controlUnitName);
    if (currentActivity) {
      let volumeDevice: HarmonyDevice =
        this._harmonyDataProvider.getDeviceByName(currentActivity.VolumeDevice);
      await this._harmonyDataProvider.sendCommand(
        volumeDownCommand,
        volumeDevice
      );
    }
  };
}
